const mix = require('laravel-mix');
const { exec } = require('child_process');

const shaCmd = "cat public/js/app.js | openssl dgst -sha512 -binary | openssl base64 -A";

/*
 |--------------------------------------------------------------------------
 | Mix Asset Management
 |--------------------------------------------------------------------------
 |
 | Mix provides a clean, fluent API for defining some Webpack build steps
 | for your Laravel applications. By default, we are compiling the CSS
 | file for the application as well as bundling up all the JS files.
 |
 */

mix.js('resources/js/app.js', 'public/js')
    .vue()
    .sourceMaps()
    .after(stats => {
        exec(shaCmd, (shaError, shaStdout, shaStderr) => {
            if (shaError) {
                console.error(`shaCmd error: ${shaError.message}`);
                return;
            }
            if (shaStderr) {
                console.error(`shaCmd stderr: ${shaStderr}`);
                return;
            }
            let sha512Hash = shaStdout;
            let sedCmd = `sed -i '/^APP_JS_INTEGRITY_HASH="*/c\APP_JS_INTEGRITY_HASH="sha512-${sha512Hash}"' .env`;

            exec(sedCmd, (sedError, sedStdout, sedStderr) => {
                if (sedError) {
                    console.error(`sedCmd error: ${sedError.message}`);
                    return;
                }
                if (sedStderr) {
                    console.error(`sedCmd stderr: ${sedStderr}`);
                    return;
                }
                console.log('Replaced SHA512 hash for integrity attribute.');
            })
        })
    })
    .postCss('resources/css/app.css', 'public/css', [
        require('postcss-import'),
        require('tailwindcss'),
    ])
    .sourceMaps()
    .webpackConfig(require('./webpack.config'));

if (mix.inProduction()) {
    mix.version();
}
